@@ -1,9 +1,11 @@
 from __future__ import annotations
 
+from copy import deepcopy
 from dataclasses import dataclass, field
 from typing import Any, Dict, Tuple
 
 from ctlml_commons.util.entity_utils import separate_fields
+from ctlml_commons.util.num_utils import convert_floats
 
 
 @dataclass(frozen=True)
@@ -30,11 +32,30 @@ class Config:
     urls: Dict[str, str] = field(default_factory=dict)
     other: Dict[str, str] = field(default_factory=dict)
 
+    def serialize(self) -> Dict[str, Any]:
+        return deepcopy(self.__dict__)
+
     @classmethod
     def deserialize(cls, input_data: Dict[str, Any]) -> Config:
         known, other = cls.separate(input_data=input_data)
 
-        return cls(**known, other=other)
+        return cls(**Config.clean(input_data=known), other=other)
+
+    @classmethod
+    def clean(cls, input_data: Dict[str, Any]) -> Dict[str, Any]:
+        data: Dict[str, Any] = convert_floats(input_data, ["total_loss_threshold"])
+
+        for field in [
+            "window_length",
+            "window_secs",
+            "random_investors",
+            "error_sleep_time_sec",
+            "update_candidate_tickers_in_sec",
+            "max_order_wait_attempts",
+        ]:
+            data[field] = int(data[field])
+
+        return data
 
     @classmethod
     def separate(cls, input_data: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
