@@ -8,10 +8,12 @@ class ConfigUrlType(Enum):
     ACCOUNTS = auto()
     CANDLES = auto()
     COINBASE = auto()
+    DOW = auto()
     EXECUTOR = auto()
     MANAGER = auto()
     ROBINHOOD = auto()
     RUSSELL = auto()
+    SANDP = auto()
     STATS = auto()
     STOCKS = auto()
     TICKERS = auto()
