@@ -4,6 +4,8 @@ from copy import deepcopy
 from dataclasses import dataclass, field
 from typing import Any, Dict, Set
 
+from ctlml_commons.util.num_utils import convert_floats
+
 
 @dataclass(frozen=True)
 class Investor:
@@ -15,12 +17,11 @@ class Investor:
     num_transactions: int = 0
     symbols_held: Set[str] = field(default_factory=set)
     default_stocks: Set[str] = field(default_factory=set)
-    tracking_stocks: Set[str] = field(default_factory=set)
 
     def serialize(self) -> Dict[str, Any]:
         data: Dict[str, Any] = deepcopy(self.__dict__)
 
-        for a_set in ["symbols_held", "default_stocks", "tracking_stocks"]:
+        for a_set in ["symbols_held", "default_stocks"]:
             data[a_set] = list(data[a_set])
 
         return data
@@ -33,7 +34,11 @@ class Investor:
     def clean(cls, input_data: Dict[str, Any]) -> Dict[str, Any]:
         data = deepcopy(input_data)
 
-        for a_list in ["symbols_held", "default_stocks", "tracking_stocks"]:
+        data = convert_floats(
+            data, ["available_funds", "cash_percentage", "num_transactions", "realized_profit_loss", "starting_funds"]
+        )
+
+        for a_list in ["symbols_held", "default_stocks"]:
             data[a_list] = set(data[a_list])
 
         return data
