@@ -1,6 +1,6 @@
 import random
 import uuid
-from typing import Any, Sequence, Set
+from typing import Any, Optional, Sequence, Set
 from uuid import UUID
 
 
@@ -16,6 +16,15 @@ def get_unique_randoms(iterable: Sequence, count: int) -> Set[str]:
 def random_unique_items(iterable: Sequence, count: int) -> Set[Any]:
     return set(random.choices(iterable, k=min(len(iterable), count)))
 
+def random_unique_items(iterable: Sequence, count: int, subscript: Optional[bool] = False) -> Set[str]:
+    values: Set[str] = set()
+    num_items: int = min(len(iterable), count)
+
+    while len(values) < num_items:
+        values.add(random.choice(iterable))
+
+    return values
+
 
 def get_uuid() -> UUID:
     return uuid.uuid4()
